LiveLog — pywws v12.11_95babb0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pywws v12.11_95babb0 documentation »
- Python programs and modules »

# LiveLog

Get weather data, store it, and process it.

Run this continuously, having set what tasks are to be done.

    usage: python LiveLog.py [options] data_dir
    options are:
     -h      or --help      display this help
     -l file or --log file  write log information to file
     -v      or --verbose   increase amount of reassuring messages
    data_dir is the root directory of the weather data (e.g. /data/weather)

For more information on using `LiveLog.py`, see How to set up ‘live’ logging with pywws.

Functions

`LiveLog`(data_dir) |
`main`([argv]) |

`LiveLog.` `LiveLog`(data_dir)

`LiveLog.` `main`(argv=None)

### Navigation

- index
- modules |
- next |
- previous |
- pywws v12.11_95babb0 documentation »
- Python programs and modules »